container

Function container 

pub fn container<V>(child: V) -> Container
where V: IntoView + 'static,
👎Deprecated since 0.2.0:

Use Container::new() instead

A simple wrapper around another View

Wrapping a View with a Container allows using another set of styles completely separate from the child View that is being wrapped.