drag_window_area

Function drag_window_area 

pub fn drag_window_area<V>(child: V) -> DragWindowArea
where V: IntoView + 'static,
A view that will move the window when the mouse is dragged.

This can be used to allow dragging the window when the title bar is disabled.