pub fn stack<VT>(children: VT) -> Stackwhere
VT: ViewTuple + 'static,๐Deprecated since 0.2.0:
Use Stack::new() instead
A basic stack that is built from a tuple of views which remains static and always contains the same elements in the same order.
The children of a stack can still get reactive updates.
See also v_stack and h_stack.
Example
use floem::views::*;
stack((
text("first element"),
stack((
text("new stack"),
empty(),
)),
));