Struct KeyboardEvent
pub struct KeyboardEvent {
pub state: KeyState,
pub key: Key,
pub code: Code,
pub location: Location,
pub modifiers: Modifiers,
pub repeat: bool,
pub is_composing: bool,
}Expand description
Keyboard events are issued for all pressed and released keys.
Fields
state: KeyStateWhether the key is pressed or released.
key: KeyLogical key value.
code: CodePhysical key position.
location: LocationLocation for keys with multiple instances on common keyboards.
modifiers: ModifiersFlags for pressed modifier keys.
repeat: boolTrue if the key is currently auto-repeated.
is_composing: boolEvents with this flag should be ignored in a text editor and instead composition events should be used.
Implementations
impl KeyboardEvent
impl KeyboardEvent
pub fn key_down(key: impl Into<Key>, code: Code) -> KeyboardEvent
pub fn key_down(key: impl Into<Key>, code: Code) -> KeyboardEvent
Convenience constructor which takes key and code, sets state to
KeyState::Down, and sets everything else to default values.
pub fn key_up(key: impl Into<Key>, code: Code) -> KeyboardEvent
pub fn key_up(key: impl Into<Key>, code: Code) -> KeyboardEvent
Convenience constructor which takes key and code, sets state to
KeyState::Up, and sets everything else to default values.