pub struct Overlay { /* private fields */ }Expand description
A declarative overlay that renders content above all other views.
The overlay content remains in the view tree as a child of this view, maintaining proper parent-child lifetime semantics. Floem reparents overlay nodes in the box tree to the window root so they participate in normal z-index ordering above regular content.
Visibility can be controlled through styles on the content itself.
Example
use floem::prelude::*;
use floem::views::{Label, Overlay, Decorators};
let show_dialog = RwSignal::new(false);
Stack::vertical((
Button::new("Show Dialog").action(move || show_dialog.set(true)),
Overlay::new_dyn(move || {
let visible = show_dialog.get();
Stack::vertical((
Label::derived(|| "This is a dialog!".to_string()),
Button::new("Close").action(move || show_dialog.set(false)),
))
.style(move |s| {
s.apply_if(!visible, |s| s.hide())
.background(Color::WHITE)
.padding(20)
.border_radius(8)
})
}),
));Notes
- The overlay is positioned absolutely at the window level
- Overlay uses a default
z-index: 1so it sorts above non-overlay content - You can style the overlay content using the view returned by
Overlay::new(...) - The overlay is automatically removed when this view is cleaned up
Implementations
Sourceimpl Overlay
impl Overlay
Sourcepub fn new(child: impl IntoView + 'static) -> Overlay
pub fn new(child: impl IntoView + 'static) -> Overlay
Creates a new overlay.
Example
use floem::prelude::*;
use floem::views::{Overlay, Label};
Overlay::new("Static overlay content");Sourcepub fn base() -> Overlay
pub fn base() -> Overlay
Creates a new overlay with no child.
Example
use floem::prelude::*;
use floem::views::Overlay;
Overlay::base();Sourcepub fn new_dyn<CF, V>(child_fn: CF) -> Overlay
pub fn new_dyn<CF, V>(child_fn: CF) -> Overlay
Creates a new overlay whose child will dynamically update in response to signal changes.
Example
use floem::prelude::*;
use floem::views::{Label, Overlay};
let message = RwSignal::new("Loading...".to_string());
Overlay::new_dyn(move || Label::new(message.get()));Trait Implementations
Sourceimpl ParentView for Overlay
impl ParentView for Overlay
Sourcefn scope(&self) -> Option<Scope>
fn scope(&self) -> Option<Scope>
Sourcefn child(self, child: impl IntoView + 'static) -> Self
fn child(self, child: impl IntoView + 'static) -> Self
Sourcefn children(self, children: impl IntoViewIter + 'static) -> Self
fn children(self, children: impl IntoViewIter + 'static) -> Self
Sourcefn derived_children<CF, C>(self, children_fn: CF) -> Selfwhere
CF: Fn() -> C + 'static,
C: IntoViewIter + 'static,
fn derived_children<CF, C>(self, children_fn: CF) -> Selfwhere
CF: Fn() -> C + 'static,
C: IntoViewIter + 'static,
Sourcefn stateful_child<S, SF, CF, V>(self, state_fn: SF, child_fn: CF) -> Self
fn stateful_child<S, SF, CF, V>(self, state_fn: SF, child_fn: CF) -> Self
Sourcefn keyed_children<IF, I, T, K, KF, VF, V>(
self,
items_fn: IF,
key_fn: KF,
view_fn: VF,
) -> Self
fn keyed_children<IF, I, T, K, KF, VF, V>( self, items_fn: IF, key_fn: KF, view_fn: VF, ) -> Self
Sourceimpl View for Overlay
impl View for Overlay
fn id(&self) -> ViewId
fn view_style(&self) -> Option<Style>
fn debug_name(&self) -> Cow<'static, str>
fn view_class(&self) -> Option<StyleClassRef>
Sourcefn update(&mut self, cx: &mut UpdateCx<'_>, state: Box<dyn Any>)
fn update(&mut self, cx: &mut UpdateCx<'_>, state: Box<dyn Any>)
View’s Id handle Read moreSourcefn style_pass(&mut self, cx: &mut StyleCx<'_>)
fn style_pass(&mut self, cx: &mut StyleCx<'_>)
Sourcefn event_capture(&mut self, _cx: &mut EventCx<'_>) -> EventPropagation
fn event_capture(&mut self, _cx: &mut EventCx<'_>) -> EventPropagation
Sourcefn event(&mut self, _cx: &mut EventCx<'_>) -> EventPropagation
fn event(&mut self, _cx: &mut EventCx<'_>) -> EventPropagation
Sourcefn paint(&mut self, cx: &mut PaintCx<'_>)
fn paint(&mut self, cx: &mut PaintCx<'_>)
View-specific implementation. Called during paint traversal for this view.
Children are painted automatically by Floem.
Views should only paint their own content (backgrounds, borders, custom drawing).fn post_paint(&mut self, cx: &mut PaintCx<'_>)