Stack

Struct Stack 

pub struct Stack { /* private fields */ }
A collection of static views. See stack and stack_from_iter.

The children of a stack can still get reactive updates.

Implementations

Source

impl Stack

pub fn new(children: impl IntoViewIter) -> Stack

Creates a new stack from any type that implements IntoViewIter.

This accepts arrays, tuples, vectors, slices, and iterators of views.

Example
use floem::views::*;

// From array
Stack::new([text("child 1"), text("child 2")]);

// From tuple (heterogeneous types)
Stack::new((text("label"), button("click")));

// From vec
Stack::new(vec![text("a"), text("b"), text("c")]);

// From iterator
Stack::new((0..5).map(|i| text(i)).collect::<Vec<_>>());
pub fn with_id(id: ViewId, children: impl IntoViewIter) -> Stack

Creates a new stack with a specific ViewId from a tuple of views.

This is useful for lazy view construction where the ViewId is created before the view itself.

Example
use floem::{ViewId, views::Stack};

let id = ViewId::new();
Stack::with_id(id, ("child 1", "child 2"));
pub fn from_iter<V>(children: impl IntoIterator<Item = V>) -> Stack
where V: IntoView + 'static,

Creates a new stack from an iterator of views.

Example
use floem::views::*;

Stack::from_iter((0..5).map(|i| text(i)));
pub fn from_iter_with_id<V>( id: ViewId, children: impl IntoIterator<Item = V>, direction: Option<FlexDirection>, ) -> Stack
where V: IntoView + 'static,

Creates a new stack with a specific ViewId from an iterator of views.

This is useful for lazy view construction where the ViewId is created before the view itself. Unlike with_id, this method pre-converts all views before setting children, avoiding potential RefCell borrow conflicts.

Example
use floem::{ViewId, views::*};

let id = ViewId::new();
Stack::from_iter_with_id(id, (0..5).map(|i| text(i)), None);
pub fn horizontal(children: impl IntoViewIter) -> Stack

Creates a new horizontal stack (row direction).

Example
use floem::views::*;

Stack::horizontal((text("left"), text("right")));
pub fn vertical(children: impl IntoViewIter) -> Stack

Creates a new vertical stack (column direction).

Example
use floem::views::*;

Stack::vertical((text("top"), text("bottom")));
pub fn horizontal_from_iter<V>(children: impl IntoIterator<Item = V>) -> Stack
where V: IntoView + 'static,

Creates a new horizontal stack from an iterator of views.

Example
use floem::views::*;

Stack::horizontal_from_iter((0..5).map(|i| text(i)));
pub fn vertical_from_iter<V>(children: impl IntoIterator<Item = V>) -> Stack
where V: IntoView + 'static,

Creates a new vertical stack from an iterator of views.

Example
use floem::views::*;

Stack::vertical_from_iter((0..5).map(|i| text(i)));
pub fn add_class_by_idx(self, class: impl Fn(usize) -> StyleClassRef) -> Stack