pub struct VirtualList<T>where
T: 'static,{
pub selection: RwSignal<Option<usize>>,
/* private fields */
}Fields
selection: RwSignal<Option<usize>>Implementations
Sourceimpl<T> VirtualList<T>
impl<T> VirtualList<T>
pub fn new<DF, I>(data_fn: DF) -> VirtualList<T>
pub fn with_view<DF, I, V>( data_fn: DF, view_fn: impl Fn(T) -> V + 'static, ) -> VirtualList<T>
pub fn with_key<DF, I, K>( data_fn: DF, key_fn: impl Fn(&T) -> K + 'static, ) -> VirtualList<T>
pub fn full<DF, I, KF, K, VF, V>( data_fn: DF, key_fn: KF, view_fn: VF, ) -> VirtualList<T>
Sourceimpl<T> VirtualList<T>where
T: 'static,
impl<T> VirtualList<T>where
T: 'static,
pub fn selection(&self) -> RwSignal<Option<usize>>
Sourcepub fn on_select(
self,
on_select: impl Fn(Option<usize>) + 'static,
) -> VirtualList<T>
pub fn on_select( self, on_select: impl Fn(Option<usize>) + 'static, ) -> VirtualList<T>
Sets a callback function to be called whenever the selection changes in the virtual list.
The callback function receives an Option<usize> parameter representing the currently
selected item index. When None, no item is selected. When Some(index), the item
at that index is currently selected.
This is a convenience helper that creates a new effect internally. Calling this method
multiple times will not override previous on_select calls - each call creates a separate
effect that will all be triggered on selection changes. For more control, you can manually
create effects using the selection signal returned by selection().
Parameters
on_select- A function that takesOption<usize>and will be called on selection changes
Returns
Returns self to allow method chaining.
Example
use floem::prelude::*;
virtual_list(
move || 1..=1000000,
|item| *item,
|index, item| format!("{index}: {item}")
)
.on_select(|selection| {
match selection {
Some(index) => println!("Selected item at index: {index}"),
None => println!("No item selected"),
}
});Methods from Deref<Target = VirtualStack<(usize, T)>>
pub fn scroll_to_idx(&self, index: usize)