pub trait HasViewId { // Required method fn view_id(&self) -> ViewId; }
A trait for types that have an associated ViewId.
ViewId
This is automatically implemented for all types that implement View, and can be manually implemented for intermediate types like [Pending].
View
Pending
Returns the ViewId associated with this value.
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Blanket implementation of HasViewId for all View types.
HasViewId