pub trait IntoViewIter {
// Required method
fn into_view_iter(self) -> impl Iterator<Item = Box<dyn View>>;
}Expand description
Trait for types that can be converted into an iterator of views.
Returns an iterator to enable lazy view construction and avoid intermediate allocations.
Required Methods
Sourcefn into_view_iter(self) -> impl Iterator<Item = Box<dyn View>>
fn into_view_iter(self) -> impl Iterator<Item = Box<dyn View>>
Converts this type into an iterator of boxed views.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".