ViewTuple

Trait ViewTuple 

pub trait ViewTuple {
    // Required methods
    fn into_views(self) -> Vec<Box<dyn View>>;
    fn stack(self, direction: FlexDirection) -> Stack;

    // Provided methods
    fn v_stack(self) -> Stack
       where Self: Sized { ... }
    fn h_stack(self) -> Stack
       where Self: Sized { ... }
}

Required Methods

fn into_views(self) -> Vec<Box<dyn View>>

fn stack(self, direction: FlexDirection) -> Stack

Provided Methods

fn v_stack(self) -> Stack
where Self: Sized,

fn h_stack(self) -> Stack
where Self: Sized,

Implementations on Foreign Types

Source

impl<A> ViewTuple for (A,)
where A: IntoView + 'static,

Source

fn into_views(self) -> Vec<Box<dyn View>>

Source

fn stack(self, direction: FlexDirection) -> Stack

Source

impl<A, B> ViewTuple for (A, B)
where A: IntoView + 'static, B: IntoView + 'static,

Source

fn into_views(self) -> Vec<Box<dyn View>>

Source

fn stack(self, direction: FlexDirection) -> Stack

Source

impl<A, B, C> ViewTuple for (A, B, C)
where A: IntoView + 'static, B: IntoView + 'static, C: IntoView + 'static,

Source

fn into_views(self) -> Vec<Box<dyn View>>

Source

fn stack(self, direction: FlexDirection) -> Stack

Source

impl<A, B, C, D> ViewTuple for (A, B, C, D)
where A: IntoView + 'static, B: IntoView + 'static, C: IntoView + 'static, D: IntoView + 'static,

Source

fn into_views(self) -> Vec<Box<dyn View>>

Source

fn stack(self, direction: FlexDirection) -> Stack

Source

impl<A, B, C, D, E> ViewTuple for (A, B, C, D, E)
where A: IntoView + 'static, B: IntoView + 'static, C: IntoView + 'static, D: IntoView + 'static, E: IntoView + 'static,

Source

fn into_views(self) -> Vec<Box<dyn View>>

Source

fn stack(self, direction: FlexDirection) -> Stack

Source

impl<A, B, C, D, E, F> ViewTuple for (A, B, C, D, E, F)
where A: IntoView + 'static, B: IntoView + 'static, C: IntoView + 'static, D: IntoView + 'static, E: IntoView + 'static, F: IntoView + 'static,

Source

fn into_views(self) -> Vec<Box<dyn View>>

Source

fn stack(self, direction: FlexDirection) -> Stack

Source

impl<A, B, C, D, E, F, G> ViewTuple for (A, B, C, D, E, F, G)
where A: IntoView + 'static, B: IntoView + 'static, C: IntoView + 'static, D: IntoView + 'static, E: IntoView + 'static, F: IntoView + 'static, G: IntoView + 'static,

Source

fn into_views(self) -> Vec<Box<dyn View>>

Source

fn stack(self, direction: FlexDirection) -> Stack

Source

impl<A, B, C, D, E, F, G, H> ViewTuple for (A, B, C, D, E, F, G, H)
where A: IntoView + 'static, B: IntoView + 'static, C: IntoView + 'static, D: IntoView + 'static, E: IntoView + 'static, F: IntoView + 'static, G: IntoView + 'static, H: IntoView + 'static,

Source

fn into_views(self) -> Vec<Box<dyn View>>

Source

fn stack(self, direction: FlexDirection) -> Stack

Source

impl<A, B, C, D, E, F, G, H, I> ViewTuple for (A, B, C, D, E, F, G, H, I)
where A: IntoView + 'static, B: IntoView + 'static, C: IntoView + 'static, D: IntoView + 'static, E: IntoView + 'static, F: IntoView + 'static, G: IntoView + 'static, H: IntoView + 'static, I: IntoView + 'static,

Source

fn into_views(self) -> Vec<Box<dyn View>>

Source

fn stack(self, direction: FlexDirection) -> Stack

Source

impl<A, B, C, D, E, F, G, H, I, J> ViewTuple for (A, B, C, D, E, F, G, H, I, J)
where A: IntoView + 'static, B: IntoView + 'static, C: IntoView + 'static, D: IntoView + 'static, E: IntoView + 'static, F: IntoView + 'static, G: IntoView + 'static, H: IntoView + 'static, I: IntoView + 'static, J: IntoView + 'static,

Source

fn into_views(self) -> Vec<Box<dyn View>>

Source

fn stack(self, direction: FlexDirection) -> Stack

Source

impl<A, B, C, D, E, F, G, H, I, J, K> ViewTuple for (A, B, C, D, E, F, G, H, I, J, K)
where A: IntoView + 'static, B: IntoView + 'static, C: IntoView + 'static, D: IntoView + 'static, E: IntoView + 'static, F: IntoView + 'static, G: IntoView + 'static, H: IntoView + 'static, I: IntoView + 'static, J: IntoView + 'static, K: IntoView + 'static,

Source

fn into_views(self) -> Vec<Box<dyn View>>

Source

fn stack(self, direction: FlexDirection) -> Stack

Source

impl<A, B, C, D, E, F, G, H, I, J, K, L> ViewTuple for (A, B, C, D, E, F, G, H, I, J, K, L)
where A: IntoView + 'static, B: IntoView + 'static, C: IntoView + 'static, D: IntoView + 'static, E: IntoView + 'static, F: IntoView + 'static, G: IntoView + 'static, H: IntoView + 'static, I: IntoView + 'static, J: IntoView + 'static, K: IntoView + 'static, L: IntoView + 'static,

Source

fn into_views(self) -> Vec<Box<dyn View>>

Source

fn stack(self, direction: FlexDirection) -> Stack

Source

impl<A, B, C, D, E, F, G, H, I, J, K, L, M> ViewTuple for (A, B, C, D, E, F, G, H, I, J, K, L, M)
where A: IntoView + 'static, B: IntoView + 'static, C: IntoView + 'static, D: IntoView + 'static, E: IntoView + 'static, F: IntoView + 'static, G: IntoView + 'static, H: IntoView + 'static, I: IntoView + 'static, J: IntoView + 'static, K: IntoView + 'static, L: IntoView + 'static, M: IntoView + 'static,

Source

fn into_views(self) -> Vec<Box<dyn View>>

Source

fn stack(self, direction: FlexDirection) -> Stack

Source

impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N> ViewTuple for (A, B, C, D, E, F, G, H, I, J, K, L, M, N)
where A: IntoView + 'static, B: IntoView + 'static, C: IntoView + 'static, D: IntoView + 'static, E: IntoView + 'static, F: IntoView + 'static, G: IntoView + 'static, H: IntoView + 'static, I: IntoView + 'static, J: IntoView + 'static, K: IntoView + 'static, L: IntoView + 'static, M: IntoView + 'static, N: IntoView + 'static,

Source

fn into_views(self) -> Vec<Box<dyn View>>

Source

fn stack(self, direction: FlexDirection) -> Stack

Source

impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O> ViewTuple for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O)
where A: IntoView + 'static, B: IntoView + 'static, C: IntoView + 'static, D: IntoView + 'static, E: IntoView + 'static, F: IntoView + 'static, G: IntoView + 'static, H: IntoView + 'static, I: IntoView + 'static, J: IntoView + 'static, K: IntoView + 'static, L: IntoView + 'static, M: IntoView + 'static, N: IntoView + 'static, O: IntoView + 'static,

Source

fn into_views(self) -> Vec<Box<dyn View>>

Source

fn stack(self, direction: FlexDirection) -> Stack

Source

impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P> ViewTuple for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P)
where A: IntoView + 'static, B: IntoView + 'static, C: IntoView + 'static, D: IntoView + 'static, E: IntoView + 'static, F: IntoView + 'static, G: IntoView + 'static, H: IntoView + 'static, I: IntoView + 'static, J: IntoView + 'static, K: IntoView + 'static, L: IntoView + 'static, M: IntoView + 'static, N: IntoView + 'static, O: IntoView + 'static, P: IntoView + 'static,

Source

fn into_views(self) -> Vec<Box<dyn View>>

Source

fn stack(self, direction: FlexDirection) -> Stack

Implementors