pub fn drag_window_area<V>(child: V) -> DragWindowAreawhere
V: IntoView + 'static,Expand description
A view that will move the window when the mouse is dragged.
This can be used to allow dragging the window when the title bar is disabled.
pub fn drag_window_area<V>(child: V) -> DragWindowAreawhere
V: IntoView + 'static,A view that will move the window when the mouse is dragged.
This can be used to allow dragging the window when the title bar is disabled.