HasViewId

Trait HasViewId 

pub trait HasViewId {
    // Required method
    fn view_id(&self) -> ViewId;
}
A trait for types that have an associated ViewId.

This is automatically implemented for all types that implement View, and can be manually implemented for intermediate types like [Pending].

Required Methods

fn view_id(&self) -> ViewId

Returns the ViewId associated with this value.

Implementors

Source

impl<T> HasViewId for LazyView<T>

Source

impl<T, K, V> HasViewId for NavigationStackBuilder<T, K, V>
where T: 'static,

Source

impl<V> HasViewId for V
where V: View,

Blanket implementation of HasViewId for all View types.