IntoViewIter

Trait IntoViewIter 

pub trait IntoViewIter {
    // Required method
    fn into_view_iter(self) -> impl Iterator<Item = Box<dyn View>>;
}
Trait for types that can be converted into an iterator of views.

Returns an iterator to enable lazy view construction and avoid intermediate allocations.

Required Methods

fn into_view_iter(self) -> impl Iterator<Item = Box<dyn View>>

Converts this type into an iterator of boxed views.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl IntoViewIter for ()

Source

fn into_view_iter(self) -> impl Iterator<Item = Box<dyn View>>

Source

impl<A> IntoViewIter for (A,)
where A: IntoView,

Source

fn into_view_iter(self) -> impl Iterator<Item = Box<dyn View>>

Source

impl<A, B> IntoViewIter for (A, B)
where A: IntoView, B: IntoView,

Source

fn into_view_iter(self) -> impl Iterator<Item = Box<dyn View>>

Source

impl<A, B, C> IntoViewIter for (A, B, C)
where A: IntoView, B: IntoView, C: IntoView,

Source

fn into_view_iter(self) -> impl Iterator<Item = Box<dyn View>>

Source

impl<A, B, C, D> IntoViewIter for (A, B, C, D)
where A: IntoView, B: IntoView, C: IntoView, D: IntoView,

Source

fn into_view_iter(self) -> impl Iterator<Item = Box<dyn View>>

Source

impl<A, B, C, D, E> IntoViewIter for (A, B, C, D, E)
where A: IntoView, B: IntoView, C: IntoView, D: IntoView, E: IntoView,

Source

fn into_view_iter(self) -> impl Iterator<Item = Box<dyn View>>

Source

impl<A, B, C, D, E, F> IntoViewIter for (A, B, C, D, E, F)
where A: IntoView, B: IntoView, C: IntoView, D: IntoView, E: IntoView, F: IntoView,

Source

fn into_view_iter(self) -> impl Iterator<Item = Box<dyn View>>

Source

impl<A, B, C, D, E, F, G> IntoViewIter for (A, B, C, D, E, F, G)
where A: IntoView, B: IntoView, C: IntoView, D: IntoView, E: IntoView, F: IntoView, G: IntoView,

Source

fn into_view_iter(self) -> impl Iterator<Item = Box<dyn View>>

Source

impl<A, B, C, D, E, F, G, H> IntoViewIter for (A, B, C, D, E, F, G, H)
where A: IntoView, B: IntoView, C: IntoView, D: IntoView, E: IntoView, F: IntoView, G: IntoView, H: IntoView,

Source

fn into_view_iter(self) -> impl Iterator<Item = Box<dyn View>>

Source

impl<A, B, C, D, E, F, G, H, I> IntoViewIter for (A, B, C, D, E, F, G, H, I)
where A: IntoView, B: IntoView, C: IntoView, D: IntoView, E: IntoView, F: IntoView, G: IntoView, H: IntoView, I: IntoView,

Source

fn into_view_iter(self) -> impl Iterator<Item = Box<dyn View>>

Source

impl<A, B, C, D, E, F, G, H, I, J> IntoViewIter for (A, B, C, D, E, F, G, H, I, J)
where A: IntoView, B: IntoView, C: IntoView, D: IntoView, E: IntoView, F: IntoView, G: IntoView, H: IntoView, I: IntoView, J: IntoView,

Source

fn into_view_iter(self) -> impl Iterator<Item = Box<dyn View>>

Source

impl<A, B, C, D, E, F, G, H, I, J, K> IntoViewIter for (A, B, C, D, E, F, G, H, I, J, K)
where A: IntoView, B: IntoView, C: IntoView, D: IntoView, E: IntoView, F: IntoView, G: IntoView, H: IntoView, I: IntoView, J: IntoView, K: IntoView,

Source

fn into_view_iter(self) -> impl Iterator<Item = Box<dyn View>>

Source

impl<A, B, C, D, E, F, G, H, I, J, K, L> IntoViewIter for (A, B, C, D, E, F, G, H, I, J, K, L)
where A: IntoView, B: IntoView, C: IntoView, D: IntoView, E: IntoView, F: IntoView, G: IntoView, H: IntoView, I: IntoView, J: IntoView, K: IntoView, L: IntoView,

Source

fn into_view_iter(self) -> impl Iterator<Item = Box<dyn View>>

Source

impl<A, B, C, D, E, F, G, H, I, J, K, L, M> IntoViewIter for (A, B, C, D, E, F, G, H, I, J, K, L, M)
where A: IntoView, B: IntoView, C: IntoView, D: IntoView, E: IntoView, F: IntoView, G: IntoView, H: IntoView, I: IntoView, J: IntoView, K: IntoView, L: IntoView, M: IntoView,

Source

fn into_view_iter(self) -> impl Iterator<Item = Box<dyn View>>

Source

impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N> IntoViewIter for (A, B, C, D, E, F, G, H, I, J, K, L, M, N)
where A: IntoView, B: IntoView, C: IntoView, D: IntoView, E: IntoView, F: IntoView, G: IntoView, H: IntoView, I: IntoView, J: IntoView, K: IntoView, L: IntoView, M: IntoView, N: IntoView,

Source

fn into_view_iter(self) -> impl Iterator<Item = Box<dyn View>>

Source

impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O> IntoViewIter for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O)
where A: IntoView, B: IntoView, C: IntoView, D: IntoView, E: IntoView, F: IntoView, G: IntoView, H: IntoView, I: IntoView, J: IntoView, K: IntoView, L: IntoView, M: IntoView, N: IntoView, O: IntoView,

Source

fn into_view_iter(self) -> impl Iterator<Item = Box<dyn View>>

Source

impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P> IntoViewIter for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P)

Source

fn into_view_iter(self) -> impl Iterator<Item = Box<dyn View>>

Source

impl<V> IntoViewIter for &[V]
where V: IntoView + Clone,

Source

fn into_view_iter(self) -> impl Iterator<Item = Box<dyn View>>

Source

impl<V> IntoViewIter for Vec<V>
where V: IntoView,

Source

fn into_view_iter(self) -> impl Iterator<Item = Box<dyn View>>

Source

impl<V, const N: usize> IntoViewIter for [V; N]
where V: IntoView,

Source

fn into_view_iter(self) -> impl Iterator<Item = Box<dyn View>>

Implementors