NavigationPath

Trait NavigationPath 

pub trait NavigationPath<T>: 'static {
    // Required method
    fn into_path_reader(self) -> Rc<dyn Fn() -> SmallVec<[T; 8]>>;
}
A path source that can produce the current navigation path on demand.

This supports plain vectors, closures, and reactive signals whose values can be converted into iterators of path items.

Required Methods

fn into_path_reader(self) -> Rc<dyn Fn() -> SmallVec<[T; 8]>>

Convert this source into an owned path reader.

Implementations on Foreign Types

Source

impl<T> NavigationPath<T> for Vec<T>
where T: Clone + 'static,

Source

fn into_path_reader(self) -> Rc<dyn Fn() -> SmallVec<[T; 8]>>

Source

impl<T, P, S> NavigationPath<T> for ReadSignal<P, S>
where ReadSignal<P, S>: SignalWith<P>, P: 'static, &'a P: for<'a> IntoIterator<Item = &'a T>, S: 'static, T: Clone + 'static,

Source

fn into_path_reader(self) -> Rc<dyn Fn() -> SmallVec<[T; 8]>>

Implementors

Source

impl<T, F, I> NavigationPath<T> for F
where F: Fn() -> I + 'static, I: IntoIterator<Item = T>,

Source

impl<T, P, S> NavigationPath<T> for RwSignal<P, S>
where RwSignal<P, S>: SignalWith<P>, P: 'static, &'a P: for<'a> IntoIterator<Item = &'a T>, S: 'static, T: Clone + 'static,