pub trait NavigationPath<T>: 'static {
// Required method
fn into_path_reader(self) -> Rc<dyn Fn() -> SmallVec<[T; 8]>>;
}Expand description
A path source that can produce the current navigation path on demand.
This supports plain vectors, closures, and reactive signals whose values can be converted into iterators of path items.
Required Methods
Sourcefn into_path_reader(self) -> Rc<dyn Fn() -> SmallVec<[T; 8]>>
fn into_path_reader(self) -> Rc<dyn Fn() -> SmallVec<[T; 8]>>
Convert this source into an owned path reader.